def wrap_file(filename: str, content: str) -> str:
    return f"<eigengen_file name=\"{filename}\">\n{content}\n</eigengen_file>"

MAGIC_STRINGS = {
    "file_start": "<eigengen_file name=",
    "file_end": "</eigengen_file>"
}

PROMPTS = {
    "system": """
    I am an AI assistant tasked with writing a polished AI assistant answer to the user prompt.
    My tasks are:
    - I write careful, considered language.
    - I use <internal_thought>, <internal_reflection> tags to mark my internal processing.
    - I remember to close <internal_thought>, <internal_reflection> tags.
    - My output contains one <internal_reasoning> block.
    - I can add multiple <internal_thought> and <internal_reflection> sub-blocks into <internal_reasoning>.
    - My actions in <internal_thought> and <internal_reflection> are:
<internal_reasoning>
<internal_thought>
    - I analyse the prompt and identify the tasks I need to perform.
    - I break down complex tasks into simpler sub-tasks.
    - I consider how my interpretation matches with the prompt.
    - I enumerate my thinking as a list
</internal_thought>

<internal_reflection>
    - I write my reflections on my thoughts.
    - I consider if my attempt at understanding the prompt is correct.
    - I reflect on the steps I've taken and think about if there would something I could do differently to reach a better result.
    - I enumerate my reflections as a list
</internal_reflection>
</internal_reasoning>
    - I remember to close <internal_reasoning> tag with </internal_reasoning>.
    - When I have completed internal reasoning, I continue processing.

""",
    "diff": """
    - I use <eigengen_file name="filename"> tag to mark the content of the files I write.
    - I remember to close <eigengen_file> tags.
    - I write <eigengen_file> </eigengen_file> segments for each file I modify.
    - I write each <eigengen_file> </eigengen_file> segment like this:
        - I write the full new version of the file.
        - I include all of the original file.
        - I continue from my thoughts and reflections and write the output.
        - I make sure I address the user prompt.
        - I add no textual explanations beyond source code comments.
""",
    "code_review": """
    - I have been provided the original proposed changes as a diff
    - The user has responded to the diff with their comments in the style of a quoted email
    - I need to carefully find the user's review comments from in between the '> ' quoted diff lines.
    - I use <eigengen_file name="filename"> tag to mark the content of the files I write.
    - I remember to close <eigengen_file> tags.
    - I write <eigengen_file> </eigengen_file> segments for each file I modify.
    - I write each <eigengen_file> </eigengen_file> segment like this:
        - I write the full new version of the file.
        - I include all of the original file.
        - I continue from my thoughts and reflections and write the output.
        - I make sure I address the user prompt.
        - I add no textual explanations beyond source code comments.
""",
    "non_diff": """
    - I write <external_output> segment for my output.
    - I continue from my thoughts and reflections, writing the output here.
    - I make sure I address the user prompt.
    - I write the full answer.
    - I write the answer so that it is self-contained.
    - I close <external_output> segment.

"""
}
